:: //////////////////////////////////////////////////////////////////////////////////////
:: //  Macnica NA                                                                      //
:: //  380 Stevens Avenue, Suite 206                                                   //
:: //  Solana Beach, CA 92075                                                          //
:: //  www.macnica-na.com                                                              //
:: //////////////////////////////////////////////////////////////////////////////////////
:: //  Mpression Odyssey Framework Source Code                                         //
:: //  This reference design file is being provided on an "as-is" basis and as an      //
:: //  accommodation and therefore all warranties, representations or guarantees of    //
:: //  any kind (whether express, implied or statutory) including, without             //
:: //  limitation, warranties of merchantability, non-infringement, or fitness for     //
:: //  a particular purpose, are specifically disclaimed.                              //
:: //////////////////////////////////////////////////////////////////////////////////////
:: //  Mpression BLE Firmware Update Utility                                   	      //
:: //  THis utility is used to update the BLE device hex firmware and also             //
:: //  allows the user to manually update the BT MAC address. There is no checking     //
:: //  of the MAC address for validity of public vs. private. 								   //
:: //////////////////////////////////////////////////////////////////////////////////////
:: //  Version:        1.1                                                             //
:: //  Version Date:   Arpil-15                                                          //
:: //////////////////////////////////////////////////////////////////////////////////////
@ECHO OFF
title Mpression BLE Firmware Update Utility
mode con:cols=100 lines=40
setlocal enabledelayedexpansion

ECHO ***********************************************************************************
ECHO ***********************************************************************************
ECHO * Project: MpressionFramework BLE Firmware Update Utility
ECHO *
ECHO * This utility will download a user selected hex file into the BCM920737 on the 
ECHO *
ECHO * Mpression Odyssey IoT Solutions kit.  It can also update the BT MAC address.
ECHO *
ECHO * Make sure the board is connected via USB and recognized by your computer.
ECHO *
ECHO ***********************************************************************************
ECHO ***********************************************************************************
ECHO.

:: Check for the SDK_INSTALL env var
if not defined SDK_INSTALL goto SET_VAR
REM else
goto SDK_CHECK

:SET_VAR
ECHO SDK_INSTALL environment variable not set...select the WICED SMART SDK installation folder...
set folder_chooser=powershell -sta "Add-Type -AssemblyName System.windows.forms|Out-Null;$f=New-Object System.Windows.Forms.FolderBrowserDialog;$f.SelectedPath='%cd%';$f.Description='Please choose a folder.';$f.ShowNewFolderButton=$true;$f.ShowDialog();$f.SelectedPath" 
for /f "delims=" %%I in ('%folder_chooser%') do set "SDK_INSTALL=%%I"
if not exist "%SDK_INSTALL%\WICED-Smart-SDK\Tools\common\Win32\perl.exe" goto SDK_ERROR
ECHO Valid SDK installation found.  Setting user environment variable.
setx SDK_INSTALL "%SDK_INSTALL%"
ECHO.
goto CONTINUE

:SDK_CHECK
:: Check for valid SDK install
if not exist "%SDK_INSTALL%\WICED-Smart-SDK\Tools\common\Win32\perl.exe" goto SDK_ERROR
ECHO Valid SDK installation found.
ECHO.
goto CONTINUE

:SDK_ERROR
ECHO ###################################################################
ECHO # ERROR - Wiced Smart SDK install NOT found at %SDK_INSTALL%
ECHO # Delete SDK_INSTALL environment variable and re-run this batch file.
ECHO ###################################################################
pause
goto:EOF

:CONTINUE
::Detect COM port
ECHO Scanning for connected Odyssey device...
set EXE_DIR=%CD%
cd /D "%SDK_INSTALL%"
"WICED-Smart-SDK\Tools\common\Win32\perl.exe" WICED-Smart-SDK/Tools/get_com_port/get_com_port.pl WICED-Smart-SDK/Tools/DetectAndId/Win32/DetAndId.exe WICED-Smart-SDK/Platforms/BCM920737TAG_Q32/BCM20737A1_IDFILE.txt %EXE_DIR%\com_port.txt > %EXE_DIR%\detect.log 2>&1 && "WICED-Smart-SDK/Tools/common/Win32/echo.exe" Device found || goto COM_ERROR
cd /D %EXE_DIR%
for /f %%I in (com_port.txt) do set COM=%%I
ECHO.

:START
:: We have good SDK and BLE - Now do either HEX or MAC update
ECHO Would you like to:
ECHO (a) Update BLE device firmware (HEX file required)
ECHO (b) Assign new BT MAC address to existing Odyssey kit (CGS file required)
ECHO Choice:
set /P SELECTION= %=%

if "%SELECTION%"=="a" goto HEX_UPDATE
if "%SELECTION%"=="b" goto MAC_UPDATE
ECHO You did not choose a valid option.  Please try again.
goto START

:COM_ERROR
:: No device detected
ECHO.
ECHO ###################################################################
ECHO # ERROR - No Odyssey detected
ECHO # Verify kit is connected and virtual COM port established
ECHO ###################################################################
ECHO.
pause
goto:EOF

:HEX_UPDATE
:: Prompt user for BLE update hex file
ECHO Select BLE device firmware update hex file...
set file_chooser=powershell "Add-Type -AssemblyName System.windows.forms|Out-Null;$f=New-Object System.Windows.Forms.OpenFileDialog;$f.InitialDirectory='%cd%';$f.Filter='Hex Files (*.hex)|*.hex';$f.showHelp=$true;$f.ShowDialog()|Out-Null;$f.FileName"
for /f "delims=" %%I in ('%file_chooser%') do set "UPDATE_FILE=%%I"
ECHO.
goto PROGRAM

:MAC_UPDATE
:: Prompt user for CGS file to update with new MAC ADDR
ECHO Select BLE device firmware CGS file to add new BT MAC address to...
set cgs_file_chooser=powershell "Add-Type -AssemblyName System.windows.forms|Out-Null;$f=New-Object System.Windows.Forms.OpenFileDialog;$f.InitialDirectory='%cd%';$f.Filter='CGS Files (*.cgs)|*.cgs';$f.showHelp=$true;$f.ShowDialog()|Out-Null;$f.FileName"
for /f "delims=" %%I in ('%cgs_file_chooser%') do set "CGS_FILE=%%I"

:: Prompt user for ne MAC address
ECHO.
ECHO Please enter the new 12 digit hexadecimal BT MAC address. 
ECHO Format = 1234567890AB
ECHO :

:GET_ADDR
set /P MAC_ADDR=%=%
set len=0
ECHO %MAC_ADDR%> mac.txt
for %%? in (mac.txt) do (set /a len=%%~z? - 2 )
if %len%==12 (goto UPDATE_CGS)

::len != 12
ECHO Please enter 12 hexadecimal digits, no spaces, colons or other delimiters...
ECHO Format = 1234567890AB
ECHO :
goto GET_ADDR

::Update CGS file, generate new HEX file and program BLE
:UPDATE_CGS
ECHO.
ECHO Executing the hex programing file generation and downloading now... 
"%SDK_INSTALL%\WICED-Smart-SDK\Tools\CGS\Win32\cgs.exe" -D "%SDK_INSTALL%/WICED-Smart-SDK/Platforms/BCM920737TAG_Q32" -O DLConfigBD_ADDRBase:%MAC_ADDR% -A 0xFF000000 -B "%SDK_INSTALL%/WICED-Smart-SDK/Platforms/BCM920737TAG_Q32/20737_EEPROM.btp" -I %CD%\Updated_BT_MAC_ADDR.hex --cgs-files %CGS_FILE%
"%SDK_INSTALL%\WICED-Smart-SDK\Tools\ChipLoad\Win32\ChipLoad.exe" -BLUETOOLMODE -PORT %COM% -BAUDRATE 115200 -MINIDRIVER "%SDK_INSTALL%/WICED-Smart-SDK/Platforms/BCM920737TAG_Q32/uart_DISABLE_EEPROM_WP_PIN1.hex" -BTP "%SDK_INSTALL%/WICED-Smart-SDK/Platforms/BCM920737TAG_Q32/20737_EEPROM.btp" -CONFIG %CD%\Updated_BT_MAC_ADDR.hex -CHECKCRC -NOVERIFY -DLMINIDRIVERCHUNKSIZE 251 > download.log 2>&1 && echo Download complete && "%SDK_INSTALL%/WICED-Smart-SDK/Tools/common/Win32/echo.exe" && echo Press RESET on BLE Sensor board to start the APP! || echo '****Download failed - Press the reset button on the device and retry ****'
ECHO.
pause
goto:CLEAN_UP

:PROGRAM
:: Program BLE with user selected HEX update file
ECHO.
ECHO Executing the download command now... 
"%SDK_INSTALL%\WICED-Smart-SDK\Tools\ChipLoad\Win32\ChipLoad.exe" -BLUETOOLMODE -PORT %COM% -BAUDRATE 115200 -MINIDRIVER "%SDK_INSTALL%/WICED-Smart-SDK/Platforms/BCM920737TAG_Q32/uart_DISABLE_EEPROM_WP_PIN1.hex" -BTP "%SDK_INSTALL%/WICED-Smart-SDK/Platforms/BCM920737TAG_Q32/20737_EEPROM.btp" -CONFIG "%UPDATE_FILE%" -CHECKCRC -NOVERIFY -DLMINIDRIVERCHUNKSIZE 251 > download.log 2>&1 && echo Download complete && "%SDK_INSTALL%/WICED-Smart-SDK/Tools/common/Win32/echo.exe" && echo Press RESET on BLE Sensor board to start the APP! || echo '****Download failed - Press the reset button on the device and retry ****'
ECHO.
pause
goto:CLEAN_UP

:CLEAN_UP
del com_port.txt
del mac.txt
del Updated_BT_MAC_ADDR.hex
del detect.log
del download.log


                                                                                                                                                                                                                    
